==> deepin-deb-installer_1.2.9.orig.tar.gz: deepin-deb-installer-1.2.9/translations/deepin-deb-installer_et.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="et" version="2.1">
<context>
    <name>DebInstaller</name>
    <message>
        <location filename="../debinstaller.cpp" line="62"/>
        <source>Dark Theme</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../debinstaller.cpp" line="88"/>
        <source>Deepin Package Manager</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../debinstaller.cpp" line="293"/>
        <source>Bulk Install</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DebListModel</name>
    <message>
        <location filename="../deblistmodel.cpp" line="57"/>
        <source>Installation failed, please check your network connection</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="59"/>
        <source>Installation failed, please check updates in Control Center</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="61"/>
        <source>Installation failed, insufficient disk space</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="64"/>
        <source>Installation Failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="296"/>
        <location filename="../deblistmodel.cpp" line="303"/>
        <source>Broken Dependencies: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="299"/>
        <source>Unmatched package architecture</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileChooseWidget</name>
    <message>
        <location filename="../filechoosewidget.cpp" line="52"/>
        <source>Drag and drop file here</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../filechoosewidget.cpp" line="76"/>
        <source>Select File</source>
        <translation>Vali fail</translation>
    </message>
</context>
<context>
    <name>MultipleInstallPage</name>
    <message>
        <location filename="../multipleinstallpage.cpp" line="41"/>
        <source>Collapse</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="41"/>
        <source>Display details</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="58"/>
        <source>Install</source>
        <translation>Paigalda</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="59"/>
        <source>Done</source>
        <translation>Valmis</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="61"/>
        <source>Back</source>
        <translation>Tagasi</translation>
    </message>
</context>
<context>
    <name>PackagesListDelegate</name>
    <message>
        <location filename="../packageslistdelegate.cpp" line="111"/>
        <source>Installing</source>
        <translation>Paigaldamine</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="115"/>
        <source>Installed</source>
        <translation>Paigaldatud</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="119"/>
        <source>Failed</source>
        <translation>Ebaõnnestus</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="144"/>
        <source>Same version installed</source>
        <translation>Sama versioon on juba paigaldatud</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="147"/>
        <source>Other version installed: %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SingleInstallPage</name>
    <message>
        <location filename="../singleinstallpage.cpp" line="109"/>
        <source>Collapse</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="109"/>
        <source>Display details</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="141"/>
        <source>Install</source>
        <translation>Paigalda</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="143"/>
        <source>Remove</source>
        <translation>Eemalda</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="145"/>
        <source>Reinstall</source>
        <translation>Paigalda uuesti</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="147"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="149"/>
        <source>Back</source>
        <translation>Tagasi</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="151"/>
        <source>Done</source>
        <translation>Valmis</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="164"/>
        <source>Version: </source>
        <translation>Versioon:</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="320"/>
        <source>Installed successfully</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="322"/>
        <source>Uninstalled successfully</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="389"/>
        <source>Other version installed: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="333"/>
        <source>Uninstall Failed</source>
        <translation>Eemaldamine ebaõnnestus</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="159"/>
        <source>Name: </source>
        <translation>Nimi:</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="387"/>
        <source>Same version installed</source>
        <translation>Sama versioon on juba paigaldatud</translation>
    </message>
</context>
<context>
    <name>UninstallConfirmPage</name>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="33"/>
        <source>Display related packages</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="33"/>
        <source>Collapse</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="46"/>
        <source>Cancel</source>
        <translation>Loobu</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="48"/>
        <source>Confirm</source>
        <translation>Kinnita</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="101"/>
        <source>Are you sure to uninstall %1?
All dependencies will also be removed</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Deepin Package Manager</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Deepin Package Manager is an application used to help users install and remove local software, supports bulk install.</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> deepin-deb-installer_1.3.0.orig.tar.gz: deepin-deb-installer-1.3.0/translations/deepin-deb-installer_et.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="et" version="2.1">
<context>
    <name>DebInstaller</name>
    <message>
        <location filename="../debinstaller.cpp" line="62"/>
        <source>Dark Theme</source>
        <translation>Tume teema</translation>
    </message>
    <message>
        <location filename="../debinstaller.cpp" line="88"/>
        <source>Deepin Package Manager</source>
        <translation>Deepin pakihaldur</translation>
    </message>
    <message>
        <location filename="../debinstaller.cpp" line="293"/>
        <source>Bulk Install</source>
        <translation>Hulgi paigaldamine</translation>
    </message>
</context>
<context>
    <name>DebListModel</name>
    <message>
        <location filename="../deblistmodel.cpp" line="57"/>
        <source>Installation failed, please check your network connection</source>
        <translation>Paigaldamine ebaõnnestus. Palun kontroli internetiühendust</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="59"/>
        <source>Installation failed, please check updates in Control Center</source>
        <translation>Paigaldamine ebaõnnestus. Palun vaata juhtpaneelilt uuendusi.</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="61"/>
        <source>Installation failed, insufficient disk space</source>
        <translation>Paigaldamine ebaõnnestus, kettal pole piisavalt vaba ruumi</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="64"/>
        <source>Installation Failed</source>
        <translation>Paigaldamine ebaõnnestus</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="296"/>
        <location filename="../deblistmodel.cpp" line="303"/>
        <source>Broken Dependencies: %1</source>
        <translation>Lahendamata sõltuvused: %1</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="299"/>
        <source>Unmatched package architecture</source>
        <translation>Sobimatu paki arhidektuur</translation>
    </message>
</context>
<context>
    <name>FileChooseWidget</name>
    <message>
        <location filename="../filechoosewidget.cpp" line="52"/>
        <source>Drag and drop file here</source>
        <translation>Lohista failid siia</translation>
    </message>
    <message>
        <location filename="../filechoosewidget.cpp" line="76"/>
        <source>Select File</source>
        <translation>Vali fail</translation>
    </message>
</context>
<context>
    <name>MultipleInstallPage</name>
    <message>
        <location filename="../multipleinstallpage.cpp" line="41"/>
        <source>Collapse</source>
        <translation>Sulge</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="41"/>
        <source>Display details</source>
        <translation>Näita üksikasju</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="58"/>
        <source>Install</source>
        <translation>Paigalda</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="59"/>
        <source>Done</source>
        <translation>Valmis</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="61"/>
        <source>Back</source>
        <translation>Tagasi</translation>
    </message>
</context>
<context>
    <name>PackagesListDelegate</name>
    <message>
        <location filename="../packageslistdelegate.cpp" line="111"/>
        <source>Installing</source>
        <translation>Paigaldamine</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="115"/>
        <source>Installed</source>
        <translation>Paigaldatud</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="119"/>
        <source>Failed</source>
        <translation>Ebaõnnestus</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="144"/>
        <source>Same version installed</source>
        <translation>Sama versioon on juba paigaldatud</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="147"/>
        <source>Other version installed: %1</source>
        <translation>Teine versioon on juba paigaldatud: %1</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage</name>
    <message>
        <location filename="../singleinstallpage.cpp" line="109"/>
        <source>Collapse</source>
        <translation>Sulge</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="109"/>
        <source>Display details</source>
        <translation>Näita üksikasju</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="141"/>
        <source>Install</source>
        <translation>Paigalda</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="143"/>
        <source>Remove</source>
        <translation>Eemalda</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="145"/>
        <source>Reinstall</source>
        <translation>Paigalda uuesti</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="147"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="149"/>
        <source>Back</source>
        <translation>Tagasi</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="151"/>
        <source>Done</source>
        <translation>Valmis</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="164"/>
        <source>Version: </source>
        <translation>Versioon:</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="320"/>
        <source>Installed successfully</source>
        <translation>Paigaldatud</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="322"/>
        <source>Uninstalled successfully</source>
        <translation>Eemaldatud</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="389"/>
        <source>Other version installed: %1</source>
        <translation>Teine versioon on juba paigaldatud: %1</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="333"/>
        <source>Uninstall Failed</source>
        <translation>Eemaldamine ebaõnnestus</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="159"/>
        <source>Name: </source>
        <translation>Nimi:</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="387"/>
        <source>Same version installed</source>
        <translation>Sama versioon on juba paigaldatud</translation>
    </message>
</context>
<context>
    <name>UninstallConfirmPage</name>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="33"/>
        <source>Display related packages</source>
        <translation>Näita seotud pakke</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="33"/>
        <source>Collapse</source>
        <translation>Sulge</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="46"/>
        <source>Cancel</source>
        <translation>Loobu</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="48"/>
        <source>Confirm</source>
        <translation>Kinnita</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="101"/>
        <source>Are you sure to uninstall %1?
All dependencies will also be removed</source>
        <translation>Oled sa kindel, et soovid %1 eemaldada?
Ka kõik selle sõltuvused eemaldatakse</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Deepin Package Manager</source>
        <translation>Deepin pakihaldur</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Deepin Package Manager is an application used to help users install and remove local software, supports bulk install.</source>
        <translation>Deepin pakihaldur on rakendus, millega kasutajad saavad arvutisse tarkvara paigaldada ja seda sealt eemaldada. Toetab ka hulgipaigaldamist.</translation>
    </message>
</context>
</TS>
